blob: d9cdf05e6058654d0776f14a2fdcd0785c5ff29a (
plain) (
blame)
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
|
# Kagamic
## TODO
- Vec_get not safe, I made a type mistake. And should be more efficient for loops
- Fix tests in release
- Benchmark 100MB file
- json.loads: 526 ms ± 77 ms per loop (mean ± std. dev. of 7 runs, 1 loop each)
- self: 348 ms (mean of 7 runs, 1 loop each). 2079 MB/s
- More modern include pragma (once)
- File structure
- Static functions for private?
- `valgrind --leak-check=full ./your_program`
- assert with error msg?
- negative numbers
## Resources
- https://nullprogram.com/blog/2023/10/08/
|